<?php

/**
 * ochStrictrouter - System plugin
 *
 * @version     0.2.1
 * @package     Joomla
 * @subpackage  plg_system_ochstrictrouter
 *
 * @author      Ruud van Lent <info@onlinecommunityhub.nl>
 * @copyright   Copyright (C) 2019 - 2021 Onlinecommunityhub (X-ceed B.V.). All rights reserved.
 * @license     GNU/GPL version 3 or later
 * @link        https://onlinecommunityhub.nl
 */


// No direct access
defined('_JEXEC') or die;

use Jaybizzle\CrawlerDetect\CrawlerDetect;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Log\Log;

/**
 * Class OchStrictrouterHelper
 *
 * @since  0.0
 */
class OchStrictrouterHelper
{
	/**
	 * Function to check if plugin should be executed
	 *
	 * @param   object    $app     Factory::getApplication()
	 * @param   registry  $params  plugin params
	 *
	 * @return  boolean   true is should execute, false if not
	 */
	public static function checkExecute($app, $params)
	{
		// Only use on front-end (not on back-end)
		if ($app->isClient('site') == false)
		{
			return false;
		}

		// Only run this plugin on HTML pages (so not on XML, etc.)
		if ($app->getDocument()->getType() !== 'html')
		{
			return false;
		}

		$component = $app->input->get('option');
		$enabledComponents = $params->get("ochstrictrouterConfiguredComponents", '');

		if (empty($enabledComponents))
		{
			$enabledComponents = array();
		}

		if ($component == 'com_finder' || (!empty($enabledComponents) && in_array($component, $enabledComponents) === false))
		{
			$logMessage = Text::sprintf('PLG_SYSTEM_OCHSTRICTROUTER_LOG_MESSAGE_COMPONENTEXCLUDED', $component);
			Log::add($logMessage, Log::INFO, 'ochstrictrouter');

			return false;
		}

		$crawlerOnly = $params->get("crawlersOnly", '1');
		$crawler     = new CrawlerDetect;

		if ($crawlerOnly)
		{
			if ($crawler->isCrawler())
			{
				return true;
			}
			else
			{
				return false;
			}
		}

		return true;
	}
}
